@@ -43,21 +43,17 @@ calc_exp_TK3 <- function( rprobs , A , np , est.xsi.index , itemwt ,
 	# call Rcpp code
 #	res <- tam.calcexp( np , rprobsL , AL ,	indexIP.no , indexIP.list2 , 
 #			est.xsi.index , CC , itemwt)
-#	res <- .Call( "TAM_CALCEXP" , np , rprobsL , AL ,	indexIP.no , 
-#			indexIP.list2 , est.xsi.index , CC , itemwt , PACKAGE="TAM" )
 # cat("  *** Ccall tam_calcexp") ; z1 <- Sys.time(); print(z1-z0) ; z0 <- z1						
 	# restructure rprobs and AL
 	rprobsL1 <- as.vector( rprobs )
 # 	AL1 <- as.vector( A  )
 # cat("  *** vector conversion") ; z1 <- Sys.time(); print(z1-z0) ; z0 <- z1				
-# 	AL1 <- .Call("redefine_vector_na" , AL1 , 0 , package="TAM")
     AL1 <- Avector
-	rprobsL1 <- .Call("redefine_vector_na" , rprobsL1, 0 , package="TAM")
-
+	rprobsL1 <- redefine_vector_na( rprobsL1, 0 )
 # cat("  *** preproc (miss) Cpp vector ") ; z1 <- Sys.time(); print(z1-z0) ; z0 <- z1			
-	res <- .Call( "TAM_CALCEXP2" , np , rprobsL1 , AL1 ,	indexIP.no , 
-			indexIP.list2 , est.xsi.index , CC , itemwt , NI*CC , TP , PACKAGE="TAM" )
+	res <- TAM_CALCEXP2( np , rprobsL1 , AL1 ,	indexIP.no , 
+			indexIP.list2 , est.xsi.index , CC , itemwt , NI*CC , TP  )
 	return(res)
-		}
+}
 		
 ##------		
